==> live-wallpaper_0.1.tar.gz: live-wallpaper-0.1/src/livewp-home-widget.h <==
/*
 * This file is part of Live Wallpaper (livewp)
 * 
 * Copyright (C) 2010 Vlad Vasiliev
 * Copyright (C) 2010 Tanya Makova
 *       for the code
 * 
 * This software is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 * 
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
*/
/*******************************************************************************/
#ifndef Animation_Wallpaper_PLUGIN_H
#define Animation_Wallpaper_PLUGIN_H

#include <glib-object.h>

G_BEGIN_DECLS


#define Animation_Wallpaper_TYPE_HOME_PLUGIN (animation_wallpaper_plugin_get_type ())

#define Animation_Wallpaper_HOME_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
                        Animation_Wallpaper_TYPE_HOME_PLUGIN, AWallpaperPlugin))

#define Animation_Wallpaper_HOME_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), \
                        Animation_Wallpaper_TYPE_HOME_PLUGIN, AWallpaperPluginClass))

#define Animation_Wallpaper_IS_HOME_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
                        Animation_Wallpaper_TYPE_HOME_PLUGIN))

#define Animation_Wallpaper_IS_HOME_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), \
                        Animation_Wallpaper_TYPE_HOME_PLUGIN))

#define Animation_Wallpaper_HOME_PLUGIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), \
                        Animation_Wallpaper_TYPE_HOME_PLUGIN, AWallpaperPluginClass))


typedef struct {
    GSList * actors;
    gint daytime;
    gint timer_type;
} Scene;
/*
typedef struct {
    time_t timestart;
    gint timeall;
    gint count;
    GtkWidget *actor;
    void (*func_change)(GtkWidget *, double);
    gint (*func_time)(gint);
} Animation;
*/

GType animation_wallpaper_plugin_get_type(void);

G_END_DECLS

void lw_settings(GtkWidget *widget, gpointer user_data);
void actor_set_position_full(GtkWidget *actor, gint x, gint y, gint z);
gint read_config(Animation_WallpaperPrivate *priv);
void save_config(Animation_WallpaperPrivate *priv);
static void init_scene(AWallpaperPlugin *desktop_plugin);
static void init_scene1(AWallpaperPlugin *desktop_plugin);

#endif

==> live-wallpaper_0.3.tar.gz: live-wallpaper-0.3/src/livewp-home-widget.h <==
/*
 * This file is part of Live Wallpaper (livewp)
 * 
 * Copyright (C) 2010 Vlad Vasiliev
 * Copyright (C) 2010 Tanya Makova
 *       for the code
 * 
 * This software is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 * 
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
*/
/*******************************************************************************/
#ifndef Animation_Wallpaper_PLUGIN_H
#define Animation_Wallpaper_PLUGIN_H

#include <glib-object.h>

G_BEGIN_DECLS


#define Animation_Wallpaper_TYPE_HOME_PLUGIN (animation_wallpaper_plugin_get_type ())

#define Animation_Wallpaper_HOME_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
                        Animation_Wallpaper_TYPE_HOME_PLUGIN, AWallpaperPlugin))

#define Animation_Wallpaper_HOME_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), \
                        Animation_Wallpaper_TYPE_HOME_PLUGIN, AWallpaperPluginClass))

#define Animation_Wallpaper_IS_HOME_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
                        Animation_Wallpaper_TYPE_HOME_PLUGIN))

#define Animation_Wallpaper_IS_HOME_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), \
                        Animation_Wallpaper_TYPE_HOME_PLUGIN))

#define Animation_Wallpaper_HOME_PLUGIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), \
                        Animation_Wallpaper_TYPE_HOME_PLUGIN, AWallpaperPluginClass))


typedef struct {
    GSList * actors;
    gint daytime;
    gint timer_type;
    gint wind_orientation; // +/- 1
    double wind_angle; // [-1 .. 1]
    guint seed; /* init value for random  */
} Scene;
/*
typedef struct {
    time_t timestart;
    gint timeall;
    gint count;
    GtkWidget *actor;
    void (*func_change)(GtkWidget *, double);
    gint (*func_time)(gint);
} Animation;
*/

GType animation_wallpaper_plugin_get_type(void);

G_END_DECLS

void lw_settings(GtkWidget *widget, gpointer user_data);
void actor_set_position_full(GtkWidget *actor, gint x, gint y, gint z);
gint read_config(Animation_WallpaperPrivate *priv);
void save_config(Animation_WallpaperPrivate *priv);
static void init_scene(AWallpaperPlugin *desktop_plugin);
static void init_scene1(AWallpaperPlugin *desktop_plugin);
void create_hildon_actor(Actor *actor, AWallpaperPlugin *desktop_plugin);
void get_sun_screen_pos(double alt, double azm, gint * x, gint * y);

#endif
